Learn R Programming

joineR (version 1.0-3)

heart.valve: Heart Valve surgery

Description

This is longitudinal data on an observational study on detecting effects of different heart valves, differing on type of tissue. The data consists of longitudinal measurements on three different heart function outcomes, after surgery occurred. There are several baseline covariates available, and also survival data.

Usage

data(heart.valve)

Arguments

Format

This is a data frame in the unbalanced format, that is, with one row per observation. The data consists in columns for patient identification, time of measurements, longitudinal multiple longitudinal measurements, baseline covariates, and survival data. The column names are identified as follows:
  • num -number for patient identification
  • sex -gender of patient (0=Male and 1=Female)
  • age - age of patient at day of surgery
  • time - observed time point, with surgery date as the time zero (/years)
  • fuyrs - maximum follow up time , with surgery date as the time zero (/years)
  • status -censoring indicator (1=died and 0=lost of follow up)
  • grad -Gradient, heart function longitudinal outcome
  • log.grad -logarithm transformation, with base e, of the Gradient longitudinal outcome
  • lvmi -Left Ventricular Mass Index, standardised by mass index, heart function longitudinal outcome
  • log.lvmi -logarithm transformation, with base e, of the lvmi longitudinal outcome
  • ef -Ejection Fraction, heart function longitudinal outcome
  • bsa -body surface area, baseline covariate
  • lvh -Left Ventricular pre-surgery hypertrophy, baseline covariate (0=good and 1=bad)
  • prenyha -pre-surgery New York Heart Association (NYHA) Classification, baseline covariate (1=I/II and 3=III/IV)
  • redo -revision procedure, baseline covariates (0=no and 1=yes)
  • size -size of the valve , baseline covariate
  • con.cabg -concomitant coronary artery bypass, baseline covariate (0=no and 1=yes)
  • creat -creatinine at baseline
  • dm -diabetes at baseline (0=no and 1=yes)
  • acei -ace inhibitor at baseline (0=no and 1=yes)
  • lv -left ventricular pre-surgery function, baseline covariate (1=good and 2=moderate and 3=poor)
  • emergenc -operative urgency, baseline covariate (0=elective and 1=urgent and 3=emergency)
  • hc -high cholesterol , baseline covariate (0=absent and 1=present treated and 2=present untreated)
  • sten.reg.mix -aortic type (1=stenosis and 2=regurgitation and 3=mixed)
  • hs -valve type used in the surgery (1=Homograft=human tissue and 0=Stentless=pig tissue)

Eric Lim - Royal Brompton Hospital

References

Lim E., Ali A., Theodorou P., Sousa I., Ashrafian H., Chamageorgakis T., Duncan M., Diggle P. and Pepper J. (2007), A longitudinal study of the profile and predictors of left ventricular mass regression after stentless aortic valve replacement, The Annals of Thoracic Surgery 85 (6), June 2008, 2026-2029

Examples

Run this code
data(heart.valve)

Run the code above in your browser using DataLab