Learn R Programming

joineR (version 1.0-3)

summary.joint: Summarise a random effects joint model fit

Description

Generic function used to produce summary information from a fitted random effects joint model as represented by object of class joint.

Usage

"summary"(object, variance, ...)

Arguments

object
an object inheriting from class joint representing a fitted random effects joint model.
variance
should the variance components be output as variances or standard deviations? Defaults to variance = TRUE.
...
further arguments for the summary

Value

an object inheriting from class summary.joint with all components included in object (see joint for a full description of the components) plus the following components:
nobs
the total number of (typically longitudinal) observations (i.e. rows in an unbalanced data set).
ngrps
the number of groups in the analysed dataset, often individual subjects.

Examples

Run this code
data(heart.valve)
heart.surv <- UniqueVariables(heart.valve, 
                              var.col=c("fuyrs","status"),
                              id.col="num")
heart.long <- heart.valve[, c("num", "time", "log.lvmi")]
heart.cov <- UniqueVariables(heart.valve, 
                             c("age", "hs", "sex"), 
                             id.col = "num")
heart.valve.jd <- jointdata(longitudinal = heart.long, 
                            baseline = heart.cov, 
                            survival = heart.surv, 
                            id.col = "num", 
                            time.col = "time")
fit <- joint(data = heart.valve.jd, 
             long.formula = log.lvmi ~ 1 + time + hs, 
             surv.formula = Surv(fuyrs,status) ~ hs, 
             model = "intslope")
summary(fit)

Run the code above in your browser using DataLab