summarybal(object, Y.col, times, use = "all.obs", na.rm, ...)object. This does not have to be all of the longitudinal measurements taken and may be a subset instead.Y.col"all.obs", "complete.obs" or
"pairwise.complete.obs". Defaults to use = "all.obs"na.rm = FALSE.list with three elements: mean.vect - a matrix with the time points in the first column and the mean response vector as the second column; variance - the vector of variances for the response at the time points and cor.mtx containing the correlation matrix of the responses between each pair of time points.to.balanced.data(mental)
summarybal(mental, Y.col = 2:7, times = c(0, 1, 2, 4, 6, 8), na.rm = TRUE)
Run the code above in your browser using DataLab